@@ -209,18 +209,18 @@ ar_unknown = '{' \
                '[#NOT(you),have,no,idea,what,{that,a r,ar,augmented,reality,it,you said},{is,mean,means}]' \
                '}'
 df.add_user_transition(State.U4, State.S4_what_is_ar, ar_unknown, score=0.9)
-df.add_system_transition(State.S4_what_is_ar, State.U4, '[!#GATE() "Yeah, not everyone knows of augmented reality devices. Augmented reality is a new technology '
-                                                        'that allows images to be placed on top of what you are looking at, to show either new objects or '
-                                                        'some information about the environment. '
-                                                        'This happens either using cameras in mobile applications or from wearing a pair of special glasses. '
-                                                        'So, what do you think of that technology?"]')
-df.add_system_transition(State.S4_what_is_ar, State.STOP_AR, '"Since you do not seem to know too much about it, I think we should talk about something else. "', score=0.0)
+df.add_system_transition(State.S4_what_is_ar, State.STOP_AR, '"Yeah, not everyone knows of augmented reality devices. Augmented reality is a new technology '
+                                                        'that allows virtual images to be placed on top of what you are looking at in the real world, using either  '
+                                                        ' glasses or cameras. You should definitely check it out. Anyways, "')
+# df.add_system_transition(State.S4_what_is_ar, State.STOP_AR, '"Since you do not seem to know too much about it, I think we should talk about something else. "', score=0.0)
 df.update_state_settings(State.STOP_AR, system_multi_hop=True)
 
 df.add_user_transition(State.U4, State.dont_know_ar_reason, dont_know, score=0.8)
-df.add_system_transition(State.dont_know_ar_reason, State.U6, '"You don\'t have any ideas? That is ok. It is still a relatively new thing, so it may be hard '
-                                                              'to form an opinion. If you were to play a mobile game using A R, what would make it the most fun, '
-                                                              'do you think?"')
+df.add_system_transition(State.dont_know_ar_reason, State.STOP_AR, '"You don\'t have any ideas? That is ok. It is still a relatively new thing, so it may be hard '
+                                                              'to form an opinion. Anyways, "')
+# df.add_system_transition(State.dont_know_ar_reason, State.U6, '"You don\'t have any ideas? That is ok. It is still a relatively new thing, so it may be hard '
+#                                                               'to form an opinion. If you were to play a mobile game using A R, what would make it the most fun, '
+#                                                               'do you think?"')
 
 # Gaming
 game = r"[{game,games,gaming}]"
@@ -240,7 +240,7 @@ df.add_system_transition(State.S5A, State.U5,
                          r'what is your opinion on A R glasses"?"]')
 
 
-df.add_system_transition(State.unknown_reason, State.S5B, '"Sure. What I have heard is that "')
+df.add_system_transition(State.unknown_reason, State.S5B, '"Sure, that\'s a good point. What I have heard is that "')
 df.update_state_settings(State.S5B, system_multi_hop=True)
 
 # why not glasses
@@ -318,32 +318,15 @@ df.add_system_transition(State.S8B, State.U8,
 df.add_user_transition(State.U8, State.S9, sentence_natex,score=0.9)
 
 df.add_user_transition(State.U8, State.dont_remember_current_state, dont_know)
-df.add_system_transition(State.dont_remember_current_state, State.U9, '"That\'s alright to not have an opinion. It is a difficult question to assess the current state of mobile A R. '
-                                                                      'At the very least, do you think that augmented or virtual realities are good investments for the future?"')
+df.add_system_transition(State.dont_remember_current_state, State.END, '"That\'s alright to not have an opinion. It is a difficult question to assess the current state of mobile A R. '
+                                                                      'I think that the future of this technology is very exciting!"')
 
 # Is AR a good investment today
-df.add_system_transition(State.S9, State.U9,
-                         r'[!Do you think that augmented or virtual realities are good investments for people to make today"?"]')
-# AR/VR is developed enough
-df.add_user_transition(State.U9, State.S10A, yes_nat)
-df.add_system_transition(State.S10A, State.U10,
-                         r'[!I think so too"." Although A R and V R may seem a little gimmicky right now"," there is a lot of potential and fun to be had with '
-                         r'the current technology "!"'
-                         r'The future is very exciting and all of this is coming much quicker than we expect "!"]')
-
-# More time is still needed
-df.add_user_transition(State.U9, State.S10B, no_natex)
-df.add_system_transition(State.S10B, State.U10,
-                         r'[!A R and V R may seem not as impressive just yet"," but as more people start to invest in these products"," '
-                         r'the more content that will be created by developers "!"'
-                         r'The future is very exciting and all of this is coming much quicker than we expect "!"]')
-
-df.add_user_transition(State.U9, State.dont_know_investment, dont_know)
-df.add_system_transition(State.dont_know_investment, State.S10B, '"Yeah, I guess a lot of these questions have been difficult to answer. Anyway, I think that "')
-df.update_state_settings(State.S10B, system_multi_hop=True)
+df.add_system_transition(State.S9, State.END,
+                         r'"For sure. I think that they may not be super impressive right now, but their future is exciting!"')
 
 
-df.add_user_transition(State.U10, State.END, "/.*/")
+# df.add_user_transition(State.U10, State.END, "/.*/")
 # df.add_system_transition(State.END, State.END,
 #                          r'[!Thank you for the wonderful conversation, have a nice rest of your day "!"]')
 
@@ -363,7 +346,7 @@ df.set_error_successor(State.U5, error_successor=State.S6_ugly)
 df.set_error_successor(State.U6, error_successor=State.S7A)
 df.set_error_successor(State.U7, error_successor=State.S8C)
 df.set_error_successor(State.U8, error_successor=State.S9)
-df.set_error_successor(State.U9, error_successor=State.S10B)
+# df.set_error_successor(State.U9, error_successor=State.S10B)
 
 if __name__ == "__main__":
     #df.precache_transitions()
